==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/FixedDelayHttpDelayTypeFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import me.snowdrop.istio.api.DurationFluentImpl;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import javax.validation.Valid;
import java.lang.Long;
import java.lang.Object;
import me.snowdrop.istio.api.DurationBuilder;

public class FixedDelayHttpDelayTypeFluentImpl<A extends FixedDelayHttpDelayTypeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements FixedDelayHttpDelayTypeFluent<A>{

    private DurationBuilder fixedDelay;

    public FixedDelayHttpDelayTypeFluentImpl(){
    }
    public FixedDelayHttpDelayTypeFluentImpl(FixedDelayHttpDelayType instance){
            this.withFixedDelay(instance.getFixedDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildFixedDelay instead.
 * @return The buildable object.
 */
@Deprecated public Duration getFixedDelay(){
            return this.fixedDelay!=null?this.fixedDelay.build():null;
    }

    public Duration buildFixedDelay(){
            return this.fixedDelay!=null?this.fixedDelay.build():null;
    }

    public A withFixedDelay(Duration fixedDelay){
            _visitables.remove(this.fixedDelay);
            if (fixedDelay!=null){ this.fixedDelay= new DurationBuilder(fixedDelay); _visitables.add(this.fixedDelay);} return (A) this;
    }

    public Boolean hasFixedDelay(){
            return this.fixedDelay != null;
    }

    public A withNewFixedDelay(Integer nanos,Long seconds){
            return (A)withFixedDelay(new Duration(nanos, seconds));
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> withNewFixedDelay(){
            return new FixedDelayNestedImpl();
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> withNewFixedDelayLike(Duration item){
            return new FixedDelayNestedImpl(item);
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editFixedDelay(){
            return withNewFixedDelayLike(getFixedDelay());
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editOrNewFixedDelay(){
            return withNewFixedDelayLike(getFixedDelay() != null ? getFixedDelay(): new DurationBuilder().build());
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editOrNewFixedDelayLike(Duration item){
            return withNewFixedDelayLike(getFixedDelay() != null ? getFixedDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            FixedDelayHttpDelayTypeFluentImpl that = (FixedDelayHttpDelayTypeFluentImpl) o;
            if (fixedDelay != null ? !fixedDelay.equals(that.fixedDelay) :that.fixedDelay != null) return false;
            return true;
    }


    public class FixedDelayNestedImpl<N> extends DurationFluentImpl<FixedDelayHttpDelayTypeFluent.FixedDelayNested<N>> implements FixedDelayHttpDelayTypeFluent.FixedDelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DurationBuilder builder;
    
            FixedDelayNestedImpl(Duration item){
                    this.builder = new DurationBuilder(this, item);
            }
            FixedDelayNestedImpl(){
                    this.builder = new DurationBuilder(this);
            }
    
    public N and(){
            return (N) FixedDelayHttpDelayTypeFluentImpl.this.withFixedDelay(builder.build());
    }
    public N endFixedDelay(){
            return and();
    }

}


}

==> istio-model-1.7.7.1-sources.jar: me/snowdrop/istio/api/networking/v1alpha3/FixedDelayHttpDelayTypeFluentImpl.java <==
package me.snowdrop.istio.api.networking.v1alpha3;

import me.snowdrop.istio.api.DurationFluentImpl;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.JsonDeserializer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.SerializerProvider;
import java.lang.Boolean;
import java.lang.Override;
import com.fasterxml.jackson.core.JsonParser;
import me.snowdrop.istio.api.Duration;
import java.lang.Integer;
import java.lang.Long;
import java.lang.Object;
import me.snowdrop.istio.api.DurationBuilder;

public class FixedDelayHttpDelayTypeFluentImpl<A extends FixedDelayHttpDelayTypeFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements FixedDelayHttpDelayTypeFluent<A>{

    private DurationBuilder fixedDelay;

    public FixedDelayHttpDelayTypeFluentImpl(){
    }
    public FixedDelayHttpDelayTypeFluentImpl(FixedDelayHttpDelayType instance){
            this.withFixedDelay(instance.getFixedDelay()); 
    }

    
/**
 * This method has been deprecated, please use method buildFixedDelay instead.
 * @return The buildable object.
 */
@Deprecated public Duration getFixedDelay(){
            return this.fixedDelay!=null?this.fixedDelay.build():null;
    }

    public Duration buildFixedDelay(){
            return this.fixedDelay!=null?this.fixedDelay.build():null;
    }

    public A withFixedDelay(Duration fixedDelay){
            _visitables.get("fixedDelay").remove(this.fixedDelay);
            if (fixedDelay!=null){ this.fixedDelay= new DurationBuilder(fixedDelay); _visitables.get("fixedDelay").add(this.fixedDelay);} return (A) this;
    }

    public Boolean hasFixedDelay(){
            return this.fixedDelay != null;
    }

    public A withNewFixedDelay(Integer nanos,Long seconds){
            return (A)withFixedDelay(new Duration(nanos, seconds));
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> withNewFixedDelay(){
            return new FixedDelayNestedImpl();
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> withNewFixedDelayLike(Duration item){
            return new FixedDelayNestedImpl(item);
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editFixedDelay(){
            return withNewFixedDelayLike(getFixedDelay());
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editOrNewFixedDelay(){
            return withNewFixedDelayLike(getFixedDelay() != null ? getFixedDelay(): new DurationBuilder().build());
    }

    public FixedDelayHttpDelayTypeFluent.FixedDelayNested<A> editOrNewFixedDelayLike(Duration item){
            return withNewFixedDelayLike(getFixedDelay() != null ? getFixedDelay(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            FixedDelayHttpDelayTypeFluentImpl that = (FixedDelayHttpDelayTypeFluentImpl) o;
            if (fixedDelay != null ? !fixedDelay.equals(that.fixedDelay) :that.fixedDelay != null) return false;
            return true;
    }


    public class FixedDelayNestedImpl<N> extends DurationFluentImpl<FixedDelayHttpDelayTypeFluent.FixedDelayNested<N>> implements FixedDelayHttpDelayTypeFluent.FixedDelayNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final DurationBuilder builder;
    
            FixedDelayNestedImpl(Duration item){
                    this.builder = new DurationBuilder(this, item);
            }
            FixedDelayNestedImpl(){
                    this.builder = new DurationBuilder(this);
            }
    
    public N and(){
            return (N) FixedDelayHttpDelayTypeFluentImpl.this.withFixedDelay(builder.build());
    }
    public N endFixedDelay(){
            return and();
    }

}


}
